@@ -231,7 +231,7 @@ class Base(object):
                 value = "'%s'" % value
             sql = sql + " %s = %s," % (param, value)
 
-        sql = sql[:-1]
+        sql = sql[:-1] + ' where  '
         sql = Base.bind_conditions(sql, conditions, or_cond)
 
         self.query(sql, show_sql)
